@@ -11,7 +11,7 @@ sub check {
 
 sub run {
         my $params = shift;
-        my $inventory = $params->{inventory};
+        my $common = $params->{common};
 
         my $OSName;
         my $OSComment;
@@ -25,9 +25,16 @@ sub run {
 			
 			$h = $h->{'System Software Overview'};
 			
-			$OSName = 'Mac OS X';
-			$OSVersion = $h->{'System Version'};
-			$OSVersion =~ s/^Mac OS X //s;
+			my $SystemVersion = $h->{'System Version'};
+			if ($SystemVersion =~ /^(.*?)\s+(\d+.*)/) {
+			    $OSName=$1;
+			    $OSVersion=$2;
+			} else {
+			    # Default values
+			    $OSName="Mac OS X";
+			    $OSVersion="Unknown";
+			}
+
 		} else {
 			# we can't load the system profiler, use the basic BSD stype information
 			# Operating system informations
@@ -37,7 +44,7 @@ sub run {
 		
 		# add the uname -v as the comment, not really needed, but extra info never hurt
 		chomp($OSComment=`uname -v`);
-        $inventory->setHardware({
+        $common->setHardware({
                 OSNAME		=> $OSName,
                 OSCOMMENTS	=> $OSComment,
                 OSVERSION	=> $OSVersion,
