@@ -12,7 +12,7 @@ sub check {
 
 sub run {
     my $params = shift;
-    my $inventory = $params->{inventory};
+    my $common = $params->{common};
 
     # run the profiler to get our datatype
     my $pro = Mac::SysProfile->new();
@@ -23,10 +23,12 @@ sub run {
 
     # add the video information
     foreach my $x (keys %$h){
-        $inventory->addVideos({
+        my $memory = $h->{$x}->{'VRAM (Total)'};
+        $memory =~ s/ MB$//;
+        $common->addVideo({
                 'NAME'        => $x,
                 'CHIPSET'     => $h->{$x}->{'Chipset Model'},
-                'MEMORY'    => $h->{$x}->{'VRAM (Total)'},
+                'MEMORY'    => $memory,
         });
 
         # this doesn't work yet, need to fix the Mac::SysProfile module to not be such a hack (parser only goes down one level)
@@ -34,7 +36,9 @@ sub run {
         # apple "xml" blows. Hard.
         foreach my $display (keys %{$h->{$x}}){
             my $ref = $h->{$x}->{$display};
-            $inventory->addMonitors({
+            next unless(ref($ref) eq 'HASH');
+
+            $common->addMonitor({
                 'CAPTION'       => $ref->{'Resolution'},
                 'DESCRIPTION'   => $display,
             })
